@@ -1,10 +1,11 @@
 from starlette.applications import Starlette
 
-from dagster import DagsterInstance, check
-from dagster.cli.workspace.cli_target import get_workspace_process_context_from_kwargs
-from dagster.core.execution.compute_logs import warn_if_compute_logs_disabled
-from dagster.core.telemetry import log_workspace_stats
-from dagster.core.workspace.context import WorkspaceProcessContext
+from dagster import DagsterInstance
+from dagster import _check as check
+from dagster._cli.workspace.cli_target import get_workspace_process_context_from_kwargs
+from dagster._core.execution.compute_logs import warn_if_compute_logs_disabled
+from dagster._core.telemetry import log_workspace_stats
+from dagster._core.workspace.context import WorkspaceProcessContext
 
 from .version import __version__
 from .webserver import DagitWebserver
