@@ -27,11 +27,11 @@ from starlette.types import Message
 
 import dagster._check as check
 from dagster import __version__ as dagster_version
-from dagster.core.debug import DebugRunPayload
-from dagster.core.storage.compute_log_manager import ComputeIOType
-from dagster.core.workspace.context import BaseWorkspaceRequestContext, IWorkspaceProcessContext
-from dagster.seven import json
-from dagster.utils import Counter, traced_counter
+from dagster._core.debug import DebugRunPayload
+from dagster._core.storage.compute_log_manager import ComputeIOType
+from dagster._core.workspace.context import BaseWorkspaceRequestContext, IWorkspaceProcessContext
+from dagster._seven import json
+from dagster._utils import Counter, traced_counter
 
 from .graphql import GraphQLServer
 from .version import __version__
